use `ombutel`;

create table `xepm_hosts` (
	`host_id` int unsigned not null auto_increment,
	`label` varchar(255) not null,
	`hostname` varchar(255) not null,
	`sip_port` varchar(255) default null,
	`iax2_port` varchar(255) default null,
	`http_port` varchar(255) default null,
	`https_port` varchar(255) default null,
	primary key (`host_id`),
	unique (`label`)
);

create table `xepm_addresses` (
	`address_id` int unsigned not null auto_increment,
	`host_id` int unsigned not null,
	`type` enum('dns','ntp') not null,
	`value` varchar(255) not null,
	primary key (`address_id`),
	unique (`host_id`,`type`,`value`),
	foreign key (`host_id`) references `xepm_hosts` (`host_id`) on delete cascade
);

create table `xepm_brands` (
	`brand_id` int unsigned not null auto_increment,
	`name` varchar(255) not null,
	primary key (`brand_id`),
	unique (`name`)
);

create table `xepm_models` (
	`model_id` int unsigned not null auto_increment,
	`brand_id` int unsigned not null,
	`sip_lines` int unsigned not null,
	`iax2_lines` int unsigned not null,
	`max_modules` int unsigned not null,
	`dss_buttons` int unsigned not null,
	`name` varchar(255) not null,
	primary key (`model_id`),
	foreign key (`brand_id`) references `xepm_brands` (`brand_id`) on delete cascade
);

create table `xepm_modules` (
	`module_id` int unsigned not null auto_increment,
	`button_count` int unsigned not null,
	`name` varchar(255) not null,
	primary key (`module_id`)
);

create table `xepm_ouis` (
	`oui_id` int unsigned not null auto_increment,
	`brand_id` int unsigned not null,
	`value` binary(3) not null,
	primary key (`oui_id`),
	unique `value` (`value`),
	foreign key (`brand_id`) references `xepm_brands` (`brand_id`) on delete cascade
);

create table `xepm_timezones` (
	`timezone_id` int unsigned not null auto_increment,
	`brand_id` int unsigned default null,
	`offset` int not null,
	`name` varchar(255) not null,
	`value` varchar(255) not null,
	primary key (`timezone_id`),
	unique `brand_id` (`brand_id`,`offset`,`name`),
	foreign key (`brand_id`) references `xepm_brands` (`brand_id`) on delete cascade
);

create table `xepm_button_types` (
	`button_type_id` int unsigned not null auto_increment,
	`ident` varchar(255) not null,
	`name` varchar(255) not null,
	primary key (`button_type_id`),
	unique `ident` (`ident`,`name`)
);

create table `xepm_configuration_types` (
	`configuration_type_id` int unsigned not null auto_increment,
	`model_id` int unsigned not null,
	`ident` varchar(255) not null,
	`name` varchar(255) not null,
	primary key (`configuration_type_id`),
	unique (`model_id`,`name`),
	foreign key (`model_id`) references `xepm_models` (`model_id`) on delete cascade
);

create table `xepm_lines` (
	`line_id` int unsigned not null auto_increment,
	`ident` varchar(255) not null,
	`name` varchar(255) not null,
	primary key (`line_id`),
	unique (`ident`,`name`)
);

create table `xepm_model_lines` (
	`model_id` int unsigned not null,
	`line_id` int unsigned not null,
	`index` int unsigned not null,
	unique (`model_id`,`index`),
	unique (`model_id`,`line_id`),
	foreign key (`model_id`) references `xepm_models` (`model_id`) on delete cascade,
	foreign key (`line_id`) references `xepm_lines` (`line_id`) on delete cascade
);

create table `xepm_model_modules` (
	`model_id` int unsigned not null,
	`module_id` int unsigned not null,
	unique `model_id` (`model_id`,`module_id`),
	foreign key (`model_id`) references `xepm_models` (`model_id`) on delete cascade,
	foreign key (`module_id`) references `xepm_modules` (`module_id`) on delete cascade
);

create table `xepm_setting_types` (
	`setting_type_id` int unsigned not null auto_increment,
	`ident` varchar(255) not null,
	`name` varchar(255) not null,
	primary key (`setting_type_id`),
	unique `ident` (`ident`),
	unique `name` (`name`)
);

create table `xepm_settings` (
	`setting_id` int unsigned not null auto_increment,
	`parent_id` int unsigned default null,
	`configuration_type_id` int unsigned not null,
	`setting_type_id` int unsigned default null,
	`name` varchar(255) not null,
	`default` varchar(255) not null,
	primary key (`setting_id`),
	foreign key (`parent_id`) references `xepm_settings` (`setting_id`) on delete cascade,
	foreign key (`configuration_type_id`) references `xepm_configuration_types` (`configuration_type_id`) on delete cascade,
	foreign key (`setting_type_id`) references `xepm_setting_types` (`setting_type_id`) on delete cascade
);

create table `xepm_templates` (
	`template_id` int unsigned not null auto_increment,
	`model_id` int unsigned default null,
	`host_id` int unsigned not null,
	`timezone_id` int unsigned not null,
	`configuration_type_id` int unsigned not null,
	`name` varchar(255) not null,
	`admin_password` varchar(255) not null,
	primary key (`template_id`),
	unique `model_id` (`model_id`,`name`),
	foreign key (`model_id`) references `xepm_models` (`model_id`) on delete cascade,
	foreign key (`host_id`) references `xepm_hosts` (`host_id`) on delete cascade,
	foreign key (`timezone_id`) references `xepm_timezones` (`timezone_id`) on delete cascade,
	foreign key (`configuration_type_id`) references `xepm_configuration_types` (`configuration_type_id`) on delete cascade
);

create table `xepm_template_modules` (
	`template_id` int unsigned not null,
	`module_id` int unsigned not null,
	`index` int unsigned not null,
	unique `template_id` (`template_id`,`module_id`,`index`),
	foreign key (`template_id`) references `xepm_templates` (`template_id`) on delete cascade,
	foreign key (`module_id`) references `xepm_modules` (`module_id`) on delete cascade
);

create table `xepm_template_settings` (
	`template_id` int unsigned not null,
	`setting_id` int unsigned not null,
	`value` varchar(255) default null,
	unique `template_id` (`template_id`,`setting_id`),
	foreign key (`template_id`) references `xepm_templates` (`template_id`) on delete cascade,
	foreign key (`setting_id`) references `xepm_settings` (`setting_id`) on delete cascade
);

create table `xepm_devices` (
	`device_id` int unsigned not null auto_increment,
	`template_id` int unsigned not null,
	`timezone_id` int unsigned default null,
	`mac_address` binary(6) not null,
	primary key (`device_id`),
	unique (`mac_address`),
	foreign key (`template_id`) references `xepm_templates` (`template_id`) on delete cascade,
	foreign key (`timezone_id`) references `xepm_timezones` (`timezone_id`) on delete cascade
);

create table `xepm_device_extensions` (
	`device_id` int unsigned not null,
	`id` int unsigned not null,
	`index` int unsigned not null,
	unique (`device_id`,`index`),
	unique (`id`),
	foreign key (`id`) references `ombu_extensions` (`id`) on delete cascade
);

create table `xepm_device_modules` (
	`device_id` int unsigned not null,
	`module_id` int unsigned not null,
	`index` int unsigned not null,
	unique (`device_id`,`index`),
	foreign key (`device_id`) references `xepm_devices` (`device_id`) on delete cascade,
	foreign key (`module_id`) references `xepm_modules` (`module_id`) on delete cascade
);

create table `xepm_device_settings` (
	`device_id` int unsigned not null,
	`setting_id` int unsigned not null,
	`value` varchar(255) default null,
	unique (`device_id`,`setting_id`),
	foreign key (`device_id`) references `xepm_devices` (`device_id`) on delete cascade,
	foreign key (`setting_id`) references `xepm_settings` (`setting_id`) on delete cascade
);

create table `xepm_button_categories` (
	`category_id` int unsigned not null auto_increment,
	`ident` varchar(255) not null,
	`name` varchar(255) not null,
	primary key (`category_id`),
	unique `ident` (`ident`)
);

create table `xepm_model_button_types` (
	`model_id` int unsigned not null,
	`category_id` int unsigned not null,
	`button_type_id` int unsigned not null,
	`index` int unsigned not null,
	primary key (`model_id`,`category_id`,`index`),
	index `button_type_id` (`button_type_id`),
	index `category_id` (`category_id`),
	foreign key (`button_type_id`) references `xepm_button_types` (`button_type_id`) on delete cascade,
	foreign key (`category_id`) references `xepm_button_categories` (`category_id`) on delete cascade,
	foreign key (`model_id`) references `xepm_models` (`model_id`) on delete cascade
);
