create table `ombutel`.`ombu_diversions` (
	`diversion_id` int unsigned not null auto_increment primary key,
	`extension_id` int unsigned not null,
	`type` enum('BOSS','PEA','FWM','DND','CC','CFI','CFB','CFU','CFN') not null,
	`enabled` enum('no','yes') not null default 'no',
	unique(`extension_id`, `type`),
	foreign key (`extension_id`) references `ombutel`.`ombu_extensions`(`extension_id`) on delete cascade
) default charset=utf8 collate=utf8_unicode_ci;

create table `ombutel`.`ombu_timed_diversions` (
	`diversion_id` int unsigned not null,
	`time_group_id` int unsigned default null,
	foreign key (`diversion_id`) references `ombutel`.`ombu_diversions`(`diversion_id`) on delete cascade,
	foreign key (`time_group_id`) references `ombutel`.`ombu_time_groups`(`time_group_id`) on delete set null
) default charset=utf8 collate=utf8_unicode_ci;

create table `ombutel`.`ombu_forwarding_diversions` (
	`diversion_id` int unsigned not null,
	`time_group_id` int unsigned default null,
	`number` varchar(255) default null,
	foreign key (`diversion_id`) references `ombutel`.`ombu_diversions`(`diversion_id`) on delete cascade,
	foreign key (`time_group_id`) references `ombutel`.`ombu_time_groups`(`time_group_id`) on delete set null
) default charset=utf8 collate=utf8_unicode_ci;

create table `ombutel`.`ombu_new_pea_diversions` (
	`diversion_id` int unsigned not null,
	`time_group_id` int unsigned default null,
	`first_destination_id` int unsigned default null,
	`second_destination_id` int unsigned default null,
	`third_destination_id` int unsigned default null,
	`fourth_destination_id` int unsigned default null,
	`default_destination_id` int unsigned default null,
	foreign key (`diversion_id`) references `ombutel`.`ombu_diversions`(`diversion_id`) on delete cascade,
	foreign key (`time_group_id`) references `ombutel`.`ombu_time_groups`(`time_group_id`) on delete set null,
	foreign key (`first_destination_id`) references `ombutel`.`ombu_destinations`(`destination_id`) on delete set null,
	foreign key (`second_destination_id`) references `ombutel`.`ombu_destinations`(`destination_id`) on delete set null,
	foreign key (`third_destination_id`) references `ombutel`.`ombu_destinations`(`destination_id`) on delete set null,
	foreign key (`fourth_destination_id`) references `ombutel`.`ombu_destinations`(`destination_id`) on delete set null,
	foreign key (`default_destination_id`) references `ombutel`.`ombu_destinations`(`destination_id`) on delete set null
) default charset=utf8 collate=utf8_unicode_ci;

insert ignore into `ombutel`.`ombu_diversions` (
	`extension_id`,
	`type`,
	`enabled`
) select
	ed.`extension_id`,
	ed.`name`,
	coalesce(ed.`enable`,'no')
from `ombutel`.`ombu_extension_diversions` ed
where ed.`name` in('BOSS','PEA','FWM','DND','CC','CFI','CFB','CFN','CFU')
order by ed.`extension_diversion_id`;

insert ignore into `ombutel`.`ombu_timed_diversions`(
	`diversion_id`,
	`time_group_id`
) select
	d.`diversion_id`,
	ed.`time_group_id`
from `ombutel`.`ombu_diversions` d
left join `ombutel`.`ombu_extension_diversions` ed on (ed.`extension_id` = d.`extension_id` and ed.`name` = d.`type`)
where d.`type` in ('BOSS','FWM','DND','CC')
order by d.`diversion_id`;

insert ignore into `ombutel`.`ombu_forwarding_diversions` (
	`diversion_id`,
	`time_group_id`,
	`number`
) select
	d.`diversion_id`,
	ed.`time_group_id`,
	coalesce(ed.`destination`,'')
from `ombutel`.`ombu_diversions` d
left join `ombutel`.`ombu_extension_diversions` ed on (ed.`extension_id` = d.`extension_id` and ed.`name` = d.`type`)
where d.`type` in ('CFI','CFB','CFN','CFU')
order by d.`diversion_id`;

insert ignore into `ombutel`.`ombu_new_pea_diversions` (
	`diversion_id`,
	`time_group_id`,
	`first_destination_id`,
	`second_destination_id`,
	`third_destination_id`,
	`fourth_destination_id`,
	`default_destination_id`
) select
	d.`diversion_id`,
	ed.`time_group_id`,
	pea1.`destination_id`,
	pea2.`destination_id`,
	pea3.`destination_id`,
	pea4.`destination_id`,
	pea5.`destination_id`
from `ombutel`.`ombu_diversions` d
left join `ombutel`.`ombu_extension_diversions` ed on (ed.`extension_id` = d.`extension_id` and ed.`name` = 'PEA')
left join `ombutel`.`ombu_pea_diversions` pea1 on (pea1.`extension_id` = d.`extension_id` and pea1.`index` = 1)
left join `ombutel`.`ombu_pea_diversions` pea2 on (pea2.`extension_id` = d.`extension_id` and pea2.`index` = 2)
left join `ombutel`.`ombu_pea_diversions` pea3 on (pea3.`extension_id` = d.`extension_id` and pea3.`index` = 3)
left join `ombutel`.`ombu_pea_diversions` pea4 on (pea4.`extension_id` = d.`extension_id` and pea4.`index` = 4)
left join `ombutel`.`ombu_pea_diversions` pea5 on (pea5.`extension_id` = d.`extension_id` and pea5.`index` = 5)
where d.`type` = 'PEA'
order by d.`diversion_id`;

drop table `ombutel`.`ombu_extension_diversions`;
drop table `ombutel`.`ombu_pea_diversions`;
rename table `ombutel`.`ombu_new_pea_diversions` to `ombutel`.`ombu_pea_diversions`;
